@@ -73,7 +73,7 @@ GameCenter.
 idmap = {
     2: {
         'cat': 'punting',
-        'fields': ['punting_blk', 'punting_cnt'],
+        'fields': ['punting_blk'],
         'yds': '',
         'desc': 'Punt blocked (offense)',
         'long': 'Punt was blocked. A blocked punt is a punt that is touched '
@@ -764,8 +764,8 @@ idmap = {
     },
     95: {
         'cat': 'team',
-        'fields': ['rush_loss'],
-        'yds': 'rush_loss_yds',
+        'fields': ['rushing_loss'],
+        'yds': 'rushing_loss_yds',
         'desc': 'Tackled for a loss',
         'long': 'Tackled for a loss (TFL) is an offensive stat. A team is '
                 'charged with a TFL if its rush ends behind the line of '
@@ -787,7 +787,7 @@ idmap = {
     # See "Extra point - safety".
     102: {
         'cat': 'team',
-        'fields': ['kickoff_downed'],
+        'fields': ['kicking_downed'],
         'yds': '',
         'desc': 'Kickoff - kick downed',
         'long': 'SuperStat didn\'t have this code. A kickoff is "downed" when '
@@ -909,4 +909,13 @@ idmap = {
         'desc': 'Tackle for a loss yards',
         'long': '',
     },
+    410: {
+        'cat': 'kicking',
+        'fields': [],
+        'yds': 'kicking_all_yds',
+        'desc': 'Kickoff and length of kick',
+        'long': 'Kickoff and length of kick. Includes end zone yards '
+                'for all kicks into the end zone, including kickoffs '
+                'ending in a touchback.',
+    },
 }
